@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 
 #include <vector>
@@ -20,14 +21,9 @@ int64_t disna(
     float const* D,
     float* SEP )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-    }
     char jobcond_ = to_char( jobcond );
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
     lapack_int info_ = 0;
 
     LAPACK_sdisna(
@@ -47,14 +43,9 @@ int64_t disna(
     double const* D,
     double* SEP )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-    }
     char jobcond_ = to_char( jobcond );
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
     lapack_int info_ = 0;
 
     LAPACK_ddisna(
