@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -23,20 +24,11 @@ int64_t gbsv(
     int64_t* ipiv,
     float* B, int64_t ldb )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( (n) );
@@ -44,7 +36,7 @@ int64_t gbsv(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int ldb_ = to_lapack_int( ldb );
     lapack_int info_ = 0;
 
     LAPACK_sgbsv(
@@ -69,20 +61,11 @@ int64_t gbsv(
     int64_t* ipiv,
     double* B, int64_t ldb )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( (n) );
@@ -90,7 +73,7 @@ int64_t gbsv(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int ldb_ = to_lapack_int( ldb );
     lapack_int info_ = 0;
 
     LAPACK_dgbsv(
@@ -115,20 +98,11 @@ int64_t gbsv(
     int64_t* ipiv,
     std::complex<float>* B, int64_t ldb )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( (n) );
@@ -136,7 +110,7 @@ int64_t gbsv(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int ldb_ = to_lapack_int( ldb );
     lapack_int info_ = 0;
 
     LAPACK_cgbsv(
@@ -243,20 +217,11 @@ int64_t gbsv(
     int64_t* ipiv,
     std::complex<double>* B, int64_t ldb )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( (n) );
@@ -264,7 +229,7 @@ int64_t gbsv(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int ldb_ = to_lapack_int( ldb );
     lapack_int info_ = 0;
 
     LAPACK_zgbsv(
