@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -31,26 +32,15 @@ int64_t gbsvx(
     float* ferr,
     float* berr )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldafb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
-    lapack_int ldafb_ = (lapack_int) ldafb;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
+    lapack_int ldafb_ = to_lapack_int( ldafb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -58,8 +48,8 @@ int64_t gbsvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -107,26 +97,15 @@ int64_t gbsvx(
     double* ferr,
     double* berr )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldafb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
-    lapack_int ldafb_ = (lapack_int) ldafb;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
+    lapack_int ldafb_ = to_lapack_int( ldafb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -134,8 +113,8 @@ int64_t gbsvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -183,26 +162,15 @@ int64_t gbsvx(
     float* ferr,
     float* berr )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldafb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
-    lapack_int ldafb_ = (lapack_int) ldafb;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
+    lapack_int ldafb_ = to_lapack_int( ldafb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -210,8 +178,8 @@ int64_t gbsvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -480,26 +448,15 @@ int64_t gbsvx(
     double* ferr,
     double* berr )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(kl) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ku) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldab) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldafb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int kl_ = (lapack_int) kl;
-    lapack_int ku_ = (lapack_int) ku;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int ldab_ = (lapack_int) ldab;
-    lapack_int ldafb_ = (lapack_int) ldafb;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int kl_ = to_lapack_int( kl );
+    lapack_int ku_ = to_lapack_int( ku );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int ldab_ = to_lapack_int( ldab );
+    lapack_int ldafb_ = to_lapack_int( ldafb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -507,8 +464,8 @@ int64_t gbsvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
