@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -24,19 +25,11 @@ int64_t gelsy(
     int64_t* jpvt, float rcond,
     int64_t* rank )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldb_ = to_lapack_int( ldb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > jpvt_( &jpvt[0], &jpvt[(n)] );
@@ -44,7 +37,7 @@ int64_t gelsy(
     #else
         lapack_int* jpvt_ptr = jpvt;
     #endif
-    lapack_int rank_ = (lapack_int) *rank;
+    lapack_int rank_ = 0;  // out
     lapack_int info_ = 0;
 
     // query for workspace size
@@ -89,19 +82,11 @@ int64_t gelsy(
     int64_t* jpvt, double rcond,
     int64_t* rank )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldb_ = to_lapack_int( ldb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > jpvt_( &jpvt[0], &jpvt[(n)] );
@@ -109,7 +94,7 @@ int64_t gelsy(
     #else
         lapack_int* jpvt_ptr = jpvt;
     #endif
-    lapack_int rank_ = (lapack_int) *rank;
+    lapack_int rank_ = 0;  // out
     lapack_int info_ = 0;
 
     // query for workspace size
@@ -154,19 +139,11 @@ int64_t gelsy(
     int64_t* jpvt, float rcond,
     int64_t* rank )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldb_ = to_lapack_int( ldb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > jpvt_( &jpvt[0], &jpvt[(n)] );
@@ -174,7 +151,7 @@ int64_t gelsy(
     #else
         lapack_int* jpvt_ptr = jpvt;
     #endif
-    lapack_int rank_ = (lapack_int) *rank;
+    lapack_int rank_ = 0;  // out
     lapack_int info_ = 0;
 
     // query for workspace size
@@ -322,19 +299,11 @@ int64_t gelsy(
     int64_t* jpvt, double rcond,
     int64_t* rank )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldb_ = (lapack_int) ldb;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldb_ = to_lapack_int( ldb );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > jpvt_( &jpvt[0], &jpvt[(n)] );
@@ -342,7 +311,7 @@ int64_t gelsy(
     #else
         lapack_int* jpvt_ptr = jpvt;
     #endif
-    lapack_int rank_ = (lapack_int) *rank;
+    lapack_int rank_ = 0;  // out
     lapack_int info_ = 0;
 
     // query for workspace size
