@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -23,19 +24,11 @@ int64_t geqrt(
     float* A, int64_t lda,
     float* T, int64_t ldt )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nb_ = (lapack_int) nb;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldt_ = (lapack_int) ldt;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nb_ = to_lapack_int( nb );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldt_ = to_lapack_int( ldt );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -58,19 +51,11 @@ int64_t geqrt(
     double* A, int64_t lda,
     double* T, int64_t ldt )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nb_ = (lapack_int) nb;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldt_ = (lapack_int) ldt;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nb_ = to_lapack_int( nb );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldt_ = to_lapack_int( ldt );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -93,19 +78,11 @@ int64_t geqrt(
     std::complex<float>* A, int64_t lda,
     std::complex<float>* T, int64_t ldt )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nb_ = (lapack_int) nb;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldt_ = (lapack_int) ldt;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nb_ = to_lapack_int( nb );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldt_ = to_lapack_int( ldt );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -128,19 +105,11 @@ int64_t geqrt(
     std::complex<double>* A, int64_t lda,
     std::complex<double>* T, int64_t ldt )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(m) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldt) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int m_ = (lapack_int) m;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nb_ = (lapack_int) nb;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldt_ = (lapack_int) ldt;
+    lapack_int m_ = to_lapack_int( m );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nb_ = to_lapack_int( nb );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldt_ = to_lapack_int( ldt );
     lapack_int info_ = 0;
 
     // allocate workspace
