@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -34,23 +35,12 @@ int64_t gerfsx(
     float* err_bnds_comp, int64_t nparams,
     float* params )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
-    }
     char trans_ = to_char( trans );
     char equed_ = to_char( equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -58,10 +48,10 @@ int64_t gerfsx(
     #else
         lapack_int const* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
-    lapack_int n_err_bnds_ = (lapack_int) n_err_bnds;
-    lapack_int nparams_ = (lapack_int) nparams;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
+    lapack_int n_err_bnds_ = to_lapack_int( n_err_bnds );
+    lapack_int nparams_ = to_lapack_int( nparams );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -107,23 +97,12 @@ int64_t gerfsx(
     double* err_bnds_comp, int64_t nparams,
     double* params )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
-    }
     char trans_ = to_char( trans );
     char equed_ = to_char( equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -131,10 +110,10 @@ int64_t gerfsx(
     #else
         lapack_int const* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
-    lapack_int n_err_bnds_ = (lapack_int) n_err_bnds;
-    lapack_int nparams_ = (lapack_int) nparams;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
+    lapack_int n_err_bnds_ = to_lapack_int( n_err_bnds );
+    lapack_int nparams_ = to_lapack_int( nparams );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -180,23 +159,12 @@ int64_t gerfsx(
     float* err_bnds_comp, int64_t nparams,
     float* params )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
-    }
     char trans_ = to_char( trans );
     char equed_ = to_char( equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -204,10 +172,10 @@ int64_t gerfsx(
     #else
         lapack_int const* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
-    lapack_int n_err_bnds_ = (lapack_int) n_err_bnds;
-    lapack_int nparams_ = (lapack_int) nparams;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
+    lapack_int n_err_bnds_ = to_lapack_int( n_err_bnds );
+    lapack_int nparams_ = to_lapack_int( nparams );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -525,23 +493,12 @@ int64_t gerfsx(
     double* err_bnds_comp, int64_t nparams,
     double* params )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(n_err_bnds) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nparams) > std::numeric_limits<lapack_int>::max() );
-    }
     char trans_ = to_char( trans );
     char equed_ = to_char( equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -549,10 +506,10 @@ int64_t gerfsx(
     #else
         lapack_int const* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
-    lapack_int n_err_bnds_ = (lapack_int) n_err_bnds;
-    lapack_int nparams_ = (lapack_int) nparams;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
+    lapack_int n_err_bnds_ = to_lapack_int( n_err_bnds );
+    lapack_int nparams_ = to_lapack_int( nparams );
     lapack_int info_ = 0;
 
     // allocate workspace
