@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -32,22 +33,13 @@ int64_t gesvx(
     float* berr,
     float* rpivotgrowth )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -55,8 +47,8 @@ int64_t gesvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -106,22 +98,13 @@ int64_t gesvx(
     double* berr,
     double* rpivotgrowth )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -129,8 +112,8 @@ int64_t gesvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -180,22 +163,13 @@ int64_t gesvx(
     float* berr,
     float* rpivotgrowth )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -203,8 +177,8 @@ int64_t gesvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
@@ -465,22 +439,13 @@ int64_t gesvx(
     double* berr,
     double* rpivotgrowth )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(nrhs) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldaf) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldx) > std::numeric_limits<lapack_int>::max() );
-    }
     char fact_ = to_char( fact );
     char trans_ = to_char( trans );
     char equed_ = to_char( *equed );
-    lapack_int n_ = (lapack_int) n;
-    lapack_int nrhs_ = (lapack_int) nrhs;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldaf_ = (lapack_int) ldaf;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int nrhs_ = to_lapack_int( nrhs );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldaf_ = to_lapack_int( ldaf );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         std::vector< lapack_int > ipiv_( &ipiv[0], &ipiv[(n)] );
@@ -488,8 +453,8 @@ int64_t gesvx(
     #else
         lapack_int* ipiv_ptr = ipiv;
     #endif
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldx_ = (lapack_int) ldx;
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldx_ = to_lapack_int( ldx );
     lapack_int info_ = 0;
 
     // allocate workspace
