@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -22,13 +23,8 @@ int64_t getri(
     float* A, int64_t lda,
     int64_t const* ipiv )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int lda_ = (lapack_int) lda;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int lda_ = to_lapack_int( lda );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( max( 1, (n) ) );
@@ -73,13 +69,8 @@ int64_t getri(
     double* A, int64_t lda,
     int64_t const* ipiv )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int lda_ = (lapack_int) lda;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int lda_ = to_lapack_int( lda );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( max( 1, (n) ) );
@@ -124,13 +115,8 @@ int64_t getri(
     std::complex<float>* A, int64_t lda,
     int64_t const* ipiv )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int lda_ = (lapack_int) lda;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int lda_ = to_lapack_int( lda );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( max( 1, (n) ) );
@@ -207,13 +193,8 @@ int64_t getri(
     std::complex<double>* A, int64_t lda,
     int64_t const* ipiv )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int lda_ = (lapack_int) lda;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int lda_ = to_lapack_int( lda );
     #ifndef LAPACK_ILP64
         // 32-bit copy
         lapack::vector< lapack_int > ipiv_( max( 1, (n) ) );
