@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 
 #include <vector>
@@ -15,20 +16,15 @@ using blas::min;
 using blas::real;
 
 // -----------------------------------------------------------------------------
-/// @ingroup unitary_computational
+/// @ingroup reflector_aux_grp
 void larfg(
     int64_t n,
     float* alpha,
     float* X, int64_t incx,
     float* tau )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_slarfg(
         &n_, alpha,
@@ -36,20 +32,15 @@ void larfg(
 }
 
 // -----------------------------------------------------------------------------
-/// @ingroup unitary_computational
+/// @ingroup reflector_aux_grp
 void larfg(
     int64_t n,
     double* alpha,
     double* X, int64_t incx,
     double* tau )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_dlarfg(
         &n_, alpha,
@@ -57,20 +48,15 @@ void larfg(
 }
 
 // -----------------------------------------------------------------------------
-/// @ingroup unitary_computational
+/// @ingroup reflector_aux_grp
 void larfg(
     int64_t n,
     std::complex<float>* alpha,
     std::complex<float>* X, int64_t incx,
     std::complex<float>* tau )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_clarfg(
         &n_, (lapack_complex_float*) alpha,
@@ -134,20 +120,15 @@ void larfg(
 /// @param[out] tau
 ///     The value tau.
 ///
-/// @ingroup unitary_computational
+/// @ingroup reflector_aux_grp
 void larfg(
     int64_t n,
     std::complex<double>* alpha,
     std::complex<double>* X, int64_t incx,
     std::complex<double>* tau )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_zlarfg(
         &n_, (lapack_complex_double*) alpha,
