@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 
 #include <vector>
@@ -22,13 +23,8 @@ void lassq(
     float* scale,
     float* sumsq )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_slassq(
         &n_,
@@ -43,13 +39,8 @@ void lassq(
     double* scale,
     double* sumsq )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_dlassq(
         &n_,
@@ -64,13 +55,8 @@ void lassq(
     float* scale,
     float* sumsq )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_classq(
         &n_,
@@ -126,13 +112,8 @@ void lassq(
     double* scale,
     double* sumsq )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(incx) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int incx_ = (lapack_int) incx;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int incx_ = to_lapack_int( incx );
 
     LAPACK_zlassq(
         &n_,
