@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 #include "NoConstructAllocator.hh"
 
@@ -21,17 +22,10 @@ int64_t orghr(
     float* A, int64_t lda,
     float const* tau )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ilo) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ihi) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int ilo_ = (lapack_int) ilo;
-    lapack_int ihi_ = (lapack_int) ihi;
-    lapack_int lda_ = (lapack_int) lda;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int ilo_ = to_lapack_int( ilo );
+    lapack_int ihi_ = to_lapack_int( ihi );
+    lapack_int lda_ = to_lapack_int( lda );
     lapack_int info_ = 0;
 
     // query for workspace size
@@ -67,17 +61,10 @@ int64_t orghr(
     double* A, int64_t lda,
     double const* tau )
 {
-    // check for overflow
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ilo) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ihi) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int n_ = (lapack_int) n;
-    lapack_int ilo_ = (lapack_int) ilo;
-    lapack_int ihi_ = (lapack_int) ihi;
-    lapack_int lda_ = (lapack_int) lda;
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int ilo_ = to_lapack_int( ilo );
+    lapack_int ihi_ = to_lapack_int( ihi );
+    lapack_int lda_ = to_lapack_int( lda );
     lapack_int info_ = 0;
 
     // query for workspace size
