@@ -4,6 +4,7 @@
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
 
 #include <vector>
@@ -117,23 +118,15 @@ int64_t tgexc(
     scalar_t* Z, int64_t ldz,
     int64_t* ifst, int64_t* ilst )
 {
-    // convert arguments
-    if (sizeof(int64_t) > sizeof(lapack_int)) {
-        lapack_error_if( std::abs(n)   > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(lda) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldb) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldq) > std::numeric_limits<lapack_int>::max() );
-        lapack_error_if( std::abs(ldz) > std::numeric_limits<lapack_int>::max() );
-    }
-    lapack_int wantq_ = (lapack_int) wantq;
-    lapack_int wantz_ = (lapack_int) wantz;
-    lapack_int n_ = (lapack_int) n;
-    lapack_int lda_ = (lapack_int) lda;
-    lapack_int ldb_ = (lapack_int) ldb;
-    lapack_int ldq_ = (lapack_int) ldq;
-    lapack_int ldz_ = (lapack_int) ldz;
-    lapack_int ifst_ = (lapack_int) *ifst;
-    lapack_int ilst_ = (lapack_int) *ilst;
+    lapack_int wantq_ = to_lapack_int( wantq );
+    lapack_int wantz_ = to_lapack_int( wantz );
+    lapack_int n_ = to_lapack_int( n );
+    lapack_int lda_ = to_lapack_int( lda );
+    lapack_int ldb_ = to_lapack_int( ldb );
+    lapack_int ldq_ = to_lapack_int( ldq );
+    lapack_int ldz_ = to_lapack_int( ldz );
+    lapack_int ifst_ = to_lapack_int( *ifst );  // in,out
+    lapack_int ilst_ = to_lapack_int( *ilst );  // in,out
     lapack_int info_ = 0;
 
     if constexpr (! is_complex<scalar_t>::value) {
