@@ -114,7 +114,7 @@ void test_gtrfs_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_gtrfs( op2char(trans), n, nrhs, &DL[0], &D[0], &DU[0], &DLF[0], &DF[0], &DUF[0], &DU2[0], &ipiv_ref[0], &B[0], ldb, &X_ref[0], ldx, &ferr_ref[0], &berr_ref[0] );
+        int64_t info_ref = LAPACKE_gtrfs( to_char( trans ), n, nrhs, &DL[0], &D[0], &DU[0], &DLF[0], &DF[0], &DUF[0], &DU2[0], &ipiv_ref[0], &B[0], ldb, &X_ref[0], ldx, &ferr_ref[0], &berr_ref[0] );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_gtrfs returned error %lld\n", llong( info_ref ) );
