@@ -76,7 +76,7 @@ void test_hetrs_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_hetrs( uplo2char(uplo), n, nrhs, &A[0], lda, &ipiv_ref[0], &B_ref[0], ldb );
+        int64_t info_ref = LAPACKE_hetrs( to_char( uplo ), n, nrhs, &A[0], lda, &ipiv_ref[0], &B_ref[0], ldb );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_hetrs returned error %lld\n", llong( info_ref ) );
