@@ -73,7 +73,7 @@ void test_hpcon_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_hpcon( uplo2char(uplo), n, &AP[0], &ipiv_ref[0], anorm, &rcond_ref );
+        int64_t info_ref = LAPACKE_hpcon( to_char( uplo ), n, &AP[0], &ipiv_ref[0], anorm, &rcond_ref );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_hpcon returned error %lld\n", llong( info_ref ) );
