@@ -85,7 +85,7 @@ void test_hpgst_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_hpgst( itype, uplo2char(uplo), n, &AP_ref[0], &BP[0] );
+        int64_t info_ref = LAPACKE_hpgst( itype, to_char( uplo ), n, &AP_ref[0], &BP[0] );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_hpgst returned error %lld\n", llong( info_ref ) );
