@@ -73,7 +73,7 @@ void test_hpsv_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_hpsv( uplo2char(uplo), n, nrhs, &AP_ref[0], &ipiv_ref[0], &B_ref[0], ldb );
+        int64_t info_ref = LAPACKE_hpsv( to_char( uplo ), n, nrhs, &AP_ref[0], &ipiv_ref[0], &B_ref[0], ldb );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_hpsv returned error %lld\n", llong( info_ref ) );
