@@ -62,7 +62,7 @@ void test_hptrf_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_hptrf( uplo2char(uplo), n, &AP_ref[0], &ipiv_ref[0] );
+        int64_t info_ref = LAPACKE_hptrf( to_char( uplo ), n, &AP_ref[0], &ipiv_ref[0] );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_hptrf returned error %lld\n", llong( info_ref ) );
