@@ -61,7 +61,7 @@ void test_lacpy_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_lacpy( matrixtype2char(matrixtype), m, n, &A[0], lda, &B_ref[0], ldb );
+        int64_t info_ref = LAPACKE_lacpy( to_char( matrixtype ), m, n, &A[0], lda, &B_ref[0], ldb );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_lacpy returned error %lld\n", llong( info_ref ) );
