@@ -61,7 +61,7 @@ void test_lanht_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        real_t norm_ref = LAPACKE_lanht( norm2char(norm), n, &D[0], &E[0] );
+        real_t norm_ref = LAPACKE_lanht( to_char( norm ), n, &D[0], &E[0] );
         time = testsweeper::get_wtime() - time;
 
         params.ref_time() = time;
