@@ -66,7 +66,7 @@ void test_lansb_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        real_t norm_ref = LAPACKE_lansb( norm2char(norm), uplo2char(uplo), n, kd, &AB[0], ldab );
+        real_t norm_ref = LAPACKE_lansb( to_char( norm ), to_char( uplo ), n, kd, &AB[0], ldab );
         time = testsweeper::get_wtime() - time;
 
         params.ref_time() = time;
