@@ -25,8 +25,8 @@ void test_larfgp_work( Params& params, bool run )
     // get & mark input values
     int64_t n = params.dim.n();
     int64_t incx = params.incx();
-    scalar_t alpha_tst = params.alpha();
-    //scalar_t alpha_ref = params.alpha();
+    scalar_t alpha_tst = params.alpha.get<scalar_t>();
+    //scalar_t alpha_ref = params.alpha.get<scalar_t>();
     int64_t verbose = params.verbose();
 
     // mark non-standard output values
