@@ -22,8 +22,8 @@ void test_laset_work( Params& params, bool run )
     lapack::MatrixType matrixtype = params.matrixtype();
     int64_t m = params.dim.m();
     int64_t n = params.dim.n();
-    scalar_t alpha = params.alpha();
-    scalar_t beta = params.beta();
+    scalar_t alpha = params.alpha.get<scalar_t>();
+    scalar_t beta  = params.beta.get<scalar_t>();
     int64_t align = params.align();
     params.matrix.mark();
 
@@ -59,7 +59,7 @@ void test_laset_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_laset( matrixtype2char(matrixtype), m, n, alpha, beta, &A_ref[0], lda );
+        int64_t info_ref = LAPACKE_laset( to_char( matrixtype ), m, n, alpha, beta, &A_ref[0], lda );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_laset returned error %lld\n", llong( info_ref ) );
