@@ -122,7 +122,7 @@ void test_potrf_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_potrf( uplo2char(uplo), n, &A_ref[0], lda );
+        int64_t info_ref = LAPACKE_potrf( to_char( uplo ), n, &A_ref[0], lda );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_potrf returned error %lld\n", llong( info_ref ) );
