@@ -75,7 +75,7 @@ void test_ppequ_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_ppequ( uplo2char(uplo), n, &AP[0], &S_ref[0], &scond_ref, &amax_ref );
+        int64_t info_ref = LAPACKE_ppequ( to_char( uplo ), n, &AP[0], &S_ref[0], &scond_ref, &amax_ref );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_ppequ returned error %lld\n", llong( info_ref ) );
