@@ -82,7 +82,7 @@ void test_pptrs_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_pptrs( uplo2char(uplo), n, nrhs, &AP[0], &B_ref[0], ldb );
+        int64_t info_ref = LAPACKE_pptrs( to_char( uplo ), n, nrhs, &AP[0], &B_ref[0], ldb );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_pptrs returned error %lld\n", llong( info_ref ) );
