@@ -80,7 +80,7 @@ void test_sysv_rk_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_sysv_rk( uplo2char(uplo), n, nrhs, &A_ref[0], lda, &E_ref[0], &ipiv_ref[0], &B_ref[0], ldb );
+        int64_t info_ref = LAPACKE_sysv_rk( to_char( uplo ), n, nrhs, &A_ref[0], lda, &E_ref[0], &ipiv_ref[0], &B_ref[0], ldb );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_sysv_rk returned error %lld\n", llong( info_ref ) );
