@@ -71,7 +71,7 @@ void test_sytrf_rk_work( Params& params, bool run )
         // ---------- run reference
         testsweeper::flush_cache( params.cache() );
         time = testsweeper::get_wtime();
-        int64_t info_ref = LAPACKE_sytrf_rk( uplo2char(uplo), n, &A_ref[0], lda, &E_ref[0], &ipiv_ref[0] );
+        int64_t info_ref = LAPACKE_sytrf_rk( to_char( uplo ), n, &A_ref[0], lda, &E_ref[0], &ipiv_ref[0] );
         time = testsweeper::get_wtime() - time;
         if (info_ref != 0) {
             fprintf( stderr, "LAPACKE_sytrf_rk returned error %lld\n", llong( info_ref ) );
