@@ -157,7 +157,9 @@ wrapper_top1 = '''\
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
 
 #include "lapack.hh"
+#include "lapack_internal.hh"
 #include "lapack/fortran.h"
+#include "NoConstructAllocator.hh"
 
 '''
 
@@ -232,37 +234,37 @@ typemap = {
 
 # --------------------
 # see blas_util.hh
-uplo = ('lapack::Uplo', 'uplo2char', {
+uplo = ('lapack::Uplo', 'to_char', {
     'u': 'Upper',
     'l': 'Lower',
     'g': 'General',
 })
 
-diag = ('lapack::Diag', 'diag2char', {
+diag = ('lapack::Diag', 'to_char', {
     'n': 'NonUnit',
     'u': 'Unit',
 })
 
-op = ('lapack::Op', 'op2char', {
+op = ('lapack::Op', 'to_char', {
     'n': 'NoTrans',
     't': 'Trans',
     'c': 'ConjTrans',
 })
 
-side = ('lapack::Side', 'side2char', {
+side = ('lapack::Side', 'to_char', {
     'l': 'Left',
     'r': 'Right',
 })
 
 # --------------------
 # see lapack_util.hh
-sides = ('lapack::Sides', 'sides2char', {
+sides = ('lapack::Sides', 'to_char', {
     'l': 'Left',
     'r': 'Right',
     'b': 'Both',
 })
 
-norm = ('lapack::Norm', 'norm2char', {
+norm = ('lapack::Norm', 'to_char', {
     '1': 'One',
     'o': 'One',
     'i': 'Inf',
@@ -270,7 +272,7 @@ norm = ('lapack::Norm', 'norm2char', {
     'm': 'Max',
 })
 
-job = ('lapack::Job', 'job2char', {
+job = ('lapack::Job', 'to_char', {
     'n': 'NoVec',
     'v': 'Vec',
     'u': 'UpdateVec',
@@ -348,26 +350,26 @@ job_gesvj = ('lapack::Job', 'job_gesvj2char', {
 # -----
 
 # hseqr
-jobschur = ('lapack::JobSchur', 'jobschur2char', {
+jobschur = ('lapack::JobSchur', 'to_char', {
     'e': 'Eigenvalues',
     's': 'Schur',
 })
 
 # gees
-sort = ('lapack::Sort', 'sort2char', {
+sort = ('lapack::Sort', 'to_char', {
     'n': 'NotSorted',
     's': 'Sorted',
 })
 
 # syevx, geevx, gesvdx
-range_enum = ('lapack::Range', 'range2char', {
+range_enum = ('lapack::Range', 'to_char', {
     'a': 'All',
     'v': 'Value',
     'i': 'Index',
 })
 
 # ormbr, orgbr
-vect = ('lapack::Vect', 'vect2char', {
+vect = ('lapack::Vect', 'to_char', {
     'q': 'Q',
     'p': 'P',
     'n': 'None',
@@ -375,19 +377,19 @@ vect = ('lapack::Vect', 'vect2char', {
 })
 
 # larfb
-direction = ('lapack::Direction', 'direction2char', {
+direction = ('lapack::Direction', 'to_char', {
     'f': 'Forward',
     'b': 'Backward',
 })
 
 # larfb
-storev = ('lapack::StoreV', 'storev2char', {
+storev = ('lapack::StoreV', 'to_char', {
     'c': 'Columnwise',
     'r': 'Rowwise',
 })
 
 # lascl, laset
-matrixtype = ('lapack::MatrixType', 'matrixtype2char', {
+matrixtype = ('lapack::MatrixType', 'to_char', {
     'g': 'General',
     'l': 'Lower',
     'u': 'Upper',
@@ -398,14 +400,14 @@ matrixtype = ('lapack::MatrixType', 'matrixtype2char', {
 })
 
 # trevc
-howmany = ('lapack::HowMany', 'howmany2char', {
+howmany = ('lapack::HowMany', 'to_char', {
     'a': 'All',
     'b': 'Backtransform',
     's': 'Select',
 })
 
 # *svx, *rfsx
-equed = ('lapack::Equed', 'equed2char', {
+equed = ('lapack::Equed', 'to_char', {
     'n': 'None',
     'r': 'Row',
     'c': 'Col',
@@ -414,14 +416,14 @@ equed = ('lapack::Equed', 'equed2char', {
 })
 
 # *svx, *rfsx
-factored = ('lapack::Factored', 'factored2char', {
+factored = ('lapack::Factored', 'to_char', {
     'f': 'Factored',
     'n': 'NotFactored',
     'e': 'Equilibrate',
 })
 
 # trsen, geesx
-sense = ('lapack::Sense', 'sense2char', {
+sense = ('lapack::Sense', 'to_char', {
     'n': 'None',
     'e': 'Eigenvalues',
     'v': 'Subspace',
@@ -429,14 +431,14 @@ sense = ('lapack::Sense', 'sense2char', {
 })
 
 # disna
-jobcond = ('lapack::JobCond', 'jobcond2char', {
+jobcond = ('lapack::JobCond', 'to_char', {
     'e': 'EigenVec',
     'l': 'LeftSingularVec',
     'r': 'RightSingularVec',
 })
 
 # gebak, gebal
-balance = ('lapack::Balance', 'balance2char', {
+balance = ('lapack::Balance', 'to_char', {
     'n': 'None',
     'p': 'Permute',
     's': 'Scale',
@@ -444,17 +446,24 @@ balance = ('lapack::Balance', 'balance2char', {
 })
 
 # stebz, larrd
-order = ('lapack::Order', 'order2char', {
+order = ('lapack::Order', 'to_char', {
     'b': 'Block',
     'e': 'Entire',
 })
 
 # rowcol
-rowcol = ('lapack::RowCol', 'rowcol2char', {
+rowcol = ('lapack::RowCol', 'to_char', {
     'c': 'Col',
     'r': 'Row',
 })
 
+# lasr
+pivot = ('lapack::Pivot', 'to_char', {
+    'v': 'Variable',
+    't': 'Top',
+    'b': 'Bottom',
+})
+
 # --------------------
 # maps argument names to enum tuples
 enum_map = {
@@ -504,6 +513,7 @@ enum_map = {
     'range':        range_enum, # syevx, geevx, gesvdx
     'vect':         vect,       # ormbr, orgbr
     'direction':    direction,  # larfb
+    'direct':       direction,  # larfb
     'storev':       storev,     # larfb
     'matrixtype':   matrixtype, # lascl, laset
     'howmany':      howmany,    # gehrd
@@ -513,6 +523,7 @@ enum_map = {
     'jobcond':      jobcond,    # disna
     'balance':      balance,    # {ge,gg}{bak,bal}
     'order':        order,      # stebz, larrd
+    'pivot':        pivot,      # lasr
 }
 
 # ------------------------------------------------------------------------------
@@ -1052,7 +1063,8 @@ def parse_lapack( path ):
                 # dimensions, enums
                 arg.lname += '_'
             arg.pname = '&' + arg.lname
-        elif (arg.intent in ('out', 'in,out') and not arg.is_array and arg.dtype in ('int64_t', 'bool')):
+        elif (arg.intent in ('out', 'in,out') and not arg.is_array
+              and arg.dtype in ('int64_t', 'bool')):
             # output dimensions (nfound, rank, ...)
             arg.lname += '_'
             arg.pname = '&' + arg.lname
@@ -1320,7 +1332,6 @@ def generate_docs( func ):
 def generate_wrapper( func, header=False ):
     # --------------------
     # build list of arguments for prototype, query, and call
-    int_checks = ''
     local_vars = ''
     alloc_work = ''
     query      = ''
@@ -1359,9 +1370,9 @@ def generate_wrapper( func, header=False ):
                 query_args.append( prefix + cast + arg.pname )
                 if (arg.dtype in ('int64_t', 'bool')):
                     # integer input arrays: copy in input
-                    local_vars += (tab + '#if 1\n'
+                    local_vars += (tab + '#ifndef LAPACK_ILP64\n'
                                +   tab*2 + '// 32-bit copy\n'
-                               +   tab*2 + 'std::vector< lapack_int > ' + arg.lname + '( &' + arg.name + '[0], &' + arg.name + '[' + arg.dim + '] );\n'
+                               +   tab*2 + 'lapack::vector< lapack_int > ' + arg.lname + '( &' + arg.name + '[0], &' + arg.name + '[' + arg.dim + '] );\n'
                                +   tab*2 + 'lapack_int const* ' + arg.pname + ' = &' + arg.lname + '[0];\n'
                                +   tab + '#else\n'
                                +   tab*2 + 'lapack_int const* ' + arg.pname + ' = ' + arg.lname + ';\n'
@@ -1373,18 +1384,17 @@ def generate_wrapper( func, header=False ):
                 use_query = True
             elif (arg.is_lwork):
                 # lwork, etc. local variables; not in proto_args
-                local_vars += tab + 'lapack_int ' + arg.lname + ' = (lapack_int) ' + arg.lbound + ';\n'
+                local_vars += tab + 'lapack_int ' + arg.lname + ' = to_lapack_int( ' + arg.lbound + ' );\n'
             else:
                 proto_args.append( arg.dtype + ' ' + arg.name )
                 alias_args.append( arg.name )
                 query_args.append( prefix + cast + arg.pname )
                 if (arg.dtype in ('int64_t', 'bool')):
                     # local 32-bit copy of 64-bit int
-                    int_checks += tab*2 + 'lapack_error_if( std::abs(' + arg.name + ') > std::numeric_limits<lapack_int>::max() );\n'
-                    local_vars += tab + 'lapack_int ' + arg.lname + ' = (lapack_int) ' + arg.name + ';\n'
+                    local_vars += tab + 'lapack_int ' + arg.lname + ' = to_lapack_int( ' + arg.name + ' );\n'
                 elif (arg.is_enum):
                     enum2char = enum_map[ arg.name ][1]
-                    local_vars += tab + 'char ' + arg.lname + ' = ' + enum2char + '( ' + arg.name + ' );\n'
+                    local_vars += tab + 'char ' + arg.lname + ' = to_char( ' + arg.name + ' );\n'
                 # end
             # end
         else:
@@ -1393,10 +1403,11 @@ def generate_wrapper( func, header=False ):
                 query_args.append( prefix + cast + 'qry_' + arg.name )
                 query += tab + arg.dtype + ' qry_' + arg.name + '[1];\n'
 
+                alloc_work += tab + 'lapack::vector< ' + arg.dtype + ' > ' + arg.lname
                 if (arg.use_query):
-                    alloc_work += tab + 'std::vector< ' + arg.dtype + ' > ' + arg.lname + '( ' + func.args[i+1].lname + ' );\n'
+                    alloc_work += '( ' + func.args[i+1].lname + ' );\n'
                 else:
-                    alloc_work += tab + 'std::vector< ' + arg.dtype + ' > ' + arg.lname + '( ' + arg.dim.lower() + ' );\n'
+                    alloc_work += '( ' + arg.dim.lower() + ' );\n'
 
                 ##alloc_work += (tab + arg.dtype + '* ' + arg.name + '_'
                 ##           +   ' = new ' + arg.dtype + '[ l' + arg.name + ' ];\n')
@@ -1415,7 +1426,11 @@ def generate_wrapper( func, header=False ):
                 else:
                     proto_args.append( '\n    ' + arg.dtype + '* ' + arg.name )
                     alias_args.append( arg.name )
-                    local_vars += tab + 'lapack_int ' + arg.lname + ' = (lapack_int) *' + arg.name + ';\n'
+                    local_vars += tab + 'lapack_int ' + arg.lname + ' = '
+                    if (arg.intent == 'out'):
+                        local_vars += '0;  // out\n'
+                    else: # in,out
+                        local_vars += 'to_lapack_int( *' + arg.name + ' );  // in,out\n'
                     cleanup += tab + '*' + arg.name + ' = ' + arg.lname + ';\n'
             else:
                 # output array
@@ -1425,24 +1440,24 @@ def generate_wrapper( func, header=False ):
                 if (arg.is_array and (arg.dtype in ('int64_t', 'bool'))):
                     if (arg.intent == 'in,out'):
                         # copy in input, copy out in cleanup
-                        local_vars += (tab + '#if 1\n'
+                        local_vars += (tab + '#ifndef LAPACK_ILP64\n'
                                    +   tab*2 + '// 32-bit copy\n'
-                                   +   tab*2 + 'std::vector< lapack_int > ' + arg.lname + '( &' + arg.name + '[0], &' + arg.name + '[' + arg.dim + '] );\n'
+                                   +   tab*2 + 'lapack::vector< lapack_int > ' + arg.lname + '( &' + arg.name + '[0], &' + arg.name + '[' + arg.dim + '] );\n'
                                    +   tab*2 + 'lapack_int* ' + arg.pname + ' = &' + arg.lname + '[0];\n'
                                    +   tab + '#else\n'
                                    +   tab*2 + 'lapack_int* ' + arg.pname + ' = ' + arg.name + ';\n'
                                    +   tab + '#endif\n')
                     else:
                         # allocate w/o copy, copy out in cleanup
-                        local_vars += (tab + '#if 1\n'
+                        local_vars += (tab + '#ifndef LAPACK_ILP64\n'
                                    +   tab*2 + '// 32-bit copy\n'
-                                   +   tab*2 + 'std::vector< lapack_int > ' + arg.lname + '( ' + arg.dim + ' );\n'
+                                   +   tab*2 + 'lapack::vector< lapack_int > ' + arg.lname + '( ' + arg.dim + ' );\n'
                                    +   tab*2 + 'lapack_int* ' + arg.pname + ' = &' + arg.lname + '[0];\n'
                                    +   tab + '#else\n'
                                    +   tab*2 + 'lapack_int* ' + arg.pname + ' = ' + arg.name + ';\n'
                                    +   tab + '#endif\n')
                     # end
-                    cleanup += (tab + '#if 1\n'
+                    cleanup += (tab + '#ifndef LAPACK_ILP64\n'
                             +   tab*2 + 'std::copy( ' + arg.lname + '.begin(), ' + arg.lname + '.end(), ' + arg.name + ' );\n'
                             +   tab + '#endif\n')
             # end
@@ -1450,14 +1465,16 @@ def generate_wrapper( func, header=False ):
         i += 1
     # end
 
-    # --------------------
+    #--------------------
     # build query
     if (use_query):
         query =  ('\n'
               +   tab + '// query for workspace size\n'
               +   query
               +   tab + 'lapack_int ineg_one = -1;\n'
-              +   tab + 'LAPACK_' + func.xname + '(\n' + tab*2 + ', '.join( query_args ) + ' );\n'
+              +   tab + 'LAPACK_' + func.xname + '(\n'
+                      + tab*2 + ', '.join( query_args ) + '\n'
+              +   tab + ');\n'
               +   tab + 'if (info_ < 0) {\n'
               +   tab*2 + 'throw Error();\n'
               +   tab + '}\n')
@@ -1472,26 +1489,27 @@ def generate_wrapper( func, header=False ):
         query = ''
     # end
 
-    if (int_checks):
-        int_checks = (tab + '// check for overflow\n'
-                   +  tab + 'if (sizeof(int64_t) > sizeof(lapack_int)) {\n'
-                   +  int_checks
-                   +  tab + '}\n')
-    # end
-
+    #--------------------
     if (alloc_work):
         alloc_work = ('\n'
                    +  tab + '// allocate workspace\n'
                    +  alloc_work)
     # end
 
+    #--------------------
+    # function call
     if (func.is_func):
-        call = '\n' + tab + 'return LAPACK_' + func.xname + '(\n' + tab*2 + ', '.join( call_args ) + ' );\n'
+        call = ('\n' + tab + 'return LAPACK_' + func.xname + '(\n'
+             + tab*2 + ', '.join( call_args ) + '\n'
+             + tab + ');\n')
         if (info_throw or cleanup or info_return):
             print( 'Warning: why is info or cleanup on a function?' )
     else:
-        call = '\n' + tab + 'LAPACK_' + func.xname + '(\n' + tab*2 + ', '.join( call_args ) + ' );\n'
+        call = ('\n' + tab + 'LAPACK_' + func.xname + '(\n'
+             + tab*2 + ', '.join( call_args ) + '\n'
+             + tab + ');\n')
 
+    #--------------------
     if (header):
         txt = (func.retval + ' ' + func.name + '(\n'
             +  tab + ', '.join( proto_args )
@@ -1512,7 +1530,6 @@ def generate_wrapper( func, header=False ):
         txt = (func.retval + ' ' + func.name + '(\n'
             +  tab + ', '.join( proto_args )
             +  ' )\n{\n'
-            +  int_checks
             +  local_vars
             +  query
             +  alloc_work
